/***************************************************************************//**
 *   @file   ADF4118.h
 *   @brief  Header file of ADF4118 Driver.
 *   @author DBogdan (dragos.bogdan@analog.com)
********************************************************************************
 * Copyright 2012(c) Analog Devices, Inc.
 *
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *  - Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *  - Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *  - Neither the name of Analog Devices, Inc. nor the names of its
 *    contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *  - The use of this software may or may not infringe the patent rights
 *    of one or more patent holders.  This license does not release you
 *    from the requirement that you obtain separate licenses from these
 *    patent holders to use this software.
 *  - Use of the software either in source or binary form, must be run
 *    on or directly connected to an Analog Devices Inc. component.
 *
 * THIS SOFTWARE IS PROVIDED BY ANALOG DEVICES "AS IS" AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, NON-INFRINGEMENT,
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL ANALOG DEVICES BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, INTELLECTUAL PROPERTY RIGHTS, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
********************************************************************************
 *   SVN Revision: $WCREV$
*******************************************************************************/

/******************************************************************************/
/* ADF4118 Control Bits                                                       */
/******************************************************************************/

/* ADF4118 Data Latch */
#define ADF4118_R_COUNTER					0
#define ADF4118_N_COUNTER					1
#define ADF4118_FUNCTION_LATCH				2
#define ADF4118_INITIALIZATION_LATCH		3

/******************************************************************************/
/* ADF4118 Reference Counter Latch                                            */
/******************************************************************************/

/* ADF4118 Lock Detect Precision */
#define ADF4118_LOCK_DETECT_PRECISION(x)	((x) << 20)

/* ADF4118 Test Mode Bits */
#define ADF4118_TEST_MODE_BITS(x)			((0xF & (x)) << 16)

/* ADF4118 14-Bit Reference Counter */
#define ADF4118_14_BIT_REFERENCE_COUNTER(x)	((0x3FFF & (x)) << 2)

/******************************************************************************/
/* ADF4118 AB Counter Latch                                                   */
/******************************************************************************/

/* ADF4118 CP Gain */
#define ADF4118_CP_GAIN(x)					((x) << 20)

/* ADF4118 13-Bit B Counter */
#define ADF4118_13_BIT_B_COUNTER(x)			((0x1FFF & (x)) << 7)

/* ADF4118 5-Bit A Counter */
#define ADF4118_5_BIT_A_COUNTER(x)			((0x1F & (x)) << 2)

/******************************************************************************/
/* ADF4118 Function Latch / Initialization Latch                              */
/******************************************************************************/

/* ADF4118 Power Modes */
#define ADF4118_NORMAL_OPERATION			((0 << 19) | (0 << 3))
#define ADF4118_ASYNCHRONOUS_POWER_DOWN		((0 << 19) | (1 << 3))
#define ADF4118_SYNCHRONOUS_POWER_DOWN		((1 << 19) | (1 << 3))

/* ADF4118 Fastlock Modes */
#define ADF4118_FASTLOCK_DISABLED			((0 << 11) | (0 << 9))
#define ADF4118_FASTLOCK_MODE_1				((0 << 11) | (1 << 9))
#define ADF4118_FASTLOCK_MODE_2				((1 << 11) | (1 << 9))

/* ADF4118 Charge Pump Output */
#define ADF4118_CHARGE_PUMP_OUTPUT(x)		((x) << 8)

/* ADF4118 Phase Detector Polarity */
#define ADF4118_PHASE_DETECTOR_POLARITY(x)	((x) << 7)

/* ADF4118 Outputs */
#define ADF4118_THREE_STATE_OUTPUT			(0 << 4)
#define ADF4118_DIGITAL_LOCK_DETECT			(1 << 4)
#define ADF4118_N_DIVIDER_OUTPUT			(2 << 4)
#define ADF4118_AVDD						(3 << 4)
#define ADF4118_R_DIVIDER_OUTPUT			(4 << 4)
#define ADF4118_ANALOG_LOCK_DETECT			(5 << 4)
#define ADF4118_SERIAL_DATA_OUTPUT			(6 << 4)
#define ADF4118_DGND						(7 << 4)

/* ADF4118 Counter Operation */
#define ADF4118_COUNTER_OPERATION(x)		((x) << 2)

/******************************************************************************/
/* Functions Prototypes                                                       */
/******************************************************************************/
void ADF4118_Write3Bytes(unsigned int data);	// Writes data into a register.
unsigned char ADF4118_Init(void);				// Initializes the SPI.
